pplpy: Python interface to the Parma Polyhedra Library
======================================================

Description
-----------

PPL Python wrapper

This Python package provides a wrapper to the C++ Parma Polyhedra
Library (PPL).

The whole package started as a fork of a tiny part of the Sage software.

License
-------

GPL version 3


Upstream Contact
----------------

-  https://github.com/sagemath/pplpy
